@@ -112,7 +112,7 @@ pango_ot_info_finalizer (void *object)
  * pango_ot_info_get:
  * @face: a <type>FT_Face</type>.
  *
- * Returns the #PangoOTInfo structure for the given FreeType font.
+ * Returns the #PangoOTInfo structure for the given FreeType font face.
  *
  * Return value: the #PangoOTInfo for @face. This object will have
  * the same lifetime as @face.
@@ -148,8 +148,8 @@ is_truetype (FT_Face face)
 typedef struct _GlyphInfo GlyphInfo;
 
 struct _GlyphInfo {
-  FT_UShort glyph;
-  FT_UShort class;
+  HB_UShort glyph;
+  HB_UShort class;
 };
 
 static int
@@ -168,7 +168,7 @@ compare_glyph_info (gconstpointer a,
  */
 static gboolean
 get_glyph_class (gunichar   charcode,
-		 FT_UShort *class)
+		 HB_UShort *class)
 {
   /* For characters mapped into the Arabic Presentation forms, using properties
    * derived as we apply GSUB substitutions will be more reliable
@@ -202,8 +202,8 @@ set_unicode_charmap (FT_Face face)
   for (charmap = 0; charmap < face->num_charmaps; charmap++)
     if (face->charmaps[charmap]->encoding == ft_encoding_unicode)
       {
-	FT_Error error = FT_Set_Charmap(face, face->charmaps[charmap]);
-	return error == FT_Err_Ok;
+	HB_Error error = FT_Set_Charmap(face, face->charmaps[charmap]);
+	return error == HB_Err_Ok;
       }
 
   return FALSE;
@@ -217,10 +217,10 @@ static void
 synthesize_class_def (PangoOTInfo *info)
 {
   GArray *glyph_infos;
-  FT_UShort *glyph_indices;
-  FT_UShort *classes;
-  FT_ULong charcode;
-  FT_UInt glyph;
+  HB_UShort *glyph_indices;
+  HB_UShort *classes;
+  HB_UInt charcode;
+  HB_UInt glyph;
   unsigned int i, j;
   FT_CharMap old_charmap;
 
@@ -254,8 +254,8 @@ synthesize_class_def (PangoOTInfo *info)
    */
   g_array_sort (glyph_infos, compare_glyph_info);
 
-  glyph_indices = g_new (FT_UShort, glyph_infos->len);
-  classes = g_new (FT_UShort, glyph_infos->len);
+  glyph_indices = g_new (HB_UShort, glyph_infos->len);
+  classes = g_new (HB_UShort, glyph_infos->len);
 
   for (i = 0, j = 0; i < glyph_infos->len; i++)
     {
@@ -289,7 +289,7 @@ pango_ot_info_get_gdef (PangoOTInfo *info)
 
   if (!(info->loaded & INFO_LOADED_GDEF))
     {
-      FT_Error error;
+      HB_Error error;
 
       info->loaded |= INFO_LOADED_GDEF;
 
@@ -297,11 +297,11 @@ pango_ot_info_get_gdef (PangoOTInfo *info)
 	{
 	  error = HB_Load_GDEF_Table (info->face, &info->gdef);
 
-	  if (error && error != FT_Err_Table_Missing)
+	  if (error && error != HB_Err_Not_Covered)
 	    g_warning ("Error loading GDEF table %d", error);
 
 	  if (!info->gdef)
-	    error = HB_New_GDEF_Table (info->face, &info->gdef);
+	    error = HB_New_GDEF_Table (&info->gdef);
 
 	  if (info->gdef && !info->gdef->GlyphClassDef.loaded)
 	    synthesize_class_def (info);
@@ -318,7 +318,7 @@ pango_ot_info_get_gsub (PangoOTInfo *info)
 
   if (!(info->loaded & INFO_LOADED_GSUB))
     {
-      FT_Error error;
+      HB_Error error;
       HB_GDEF gdef = pango_ot_info_get_gdef (info);
 
       info->loaded |= INFO_LOADED_GSUB;
@@ -327,7 +327,7 @@ pango_ot_info_get_gsub (PangoOTInfo *info)
 	{
 	  error = HB_Load_GSUB_Table (info->face, &info->gsub, gdef);
 
-	  if (error && error != FT_Err_Table_Missing)
+	  if (error && error != HB_Err_Not_Covered)
 	    g_warning ("Error loading GSUB table %d", error);
 	}
     }
@@ -342,7 +342,7 @@ pango_ot_info_get_gpos (PangoOTInfo *info)
 
   if (!(info->loaded & INFO_LOADED_GPOS))
     {
-      FT_Error error;
+      HB_Error error;
       HB_GDEF gdef = pango_ot_info_get_gdef (info);
 
       info->loaded |= INFO_LOADED_GPOS;
@@ -351,7 +351,7 @@ pango_ot_info_get_gpos (PangoOTInfo *info)
 	{
 	  error = HB_Load_GPOS_Table (info->face, &info->gpos, gdef);
 
-	  if (error && error != FT_Err_Table_Missing)
+	  if (error && error != HB_Err_Not_Covered)
 	    g_warning ("Error loading GPOS table %d", error);
 	}
     }
@@ -459,7 +459,7 @@ pango_ot_info_find_script (PangoOTInfo      *info,
     }
 
   /* try with 'dflt'; MS site has had typos and many fonts use it now :( */
-  script_tag = FT_MAKE_TAG ('d', 'f', 'l', 't');
+  script_tag = PANGO_OT_TAG_MAKE ('d', 'f', 'l', 't');
 
   for (i=0; i < script_list->ScriptCount; i++)
     {
@@ -505,7 +505,7 @@ pango_ot_info_find_language (PangoOTInfo      *info,
 			     guint            *required_feature_index)
 {
   HB_ScriptList *script_list;
-  HB_Script *script;
+  HB_ScriptTable *script;
   int i;
 
   if (language_index)
@@ -538,7 +538,7 @@ pango_ot_info_find_language (PangoOTInfo      *info,
     }
 
   /* try with 'dflt'; MS site has had typos and many fonts use it now :( */
-  language_tag = FT_MAKE_TAG ('d', 'f', 'l', 't');
+  language_tag = PANGO_OT_TAG_MAKE ('d', 'f', 'l', 't');
 
   for (i = 0; i < script->LangSysCount; i++)
     {
@@ -593,7 +593,7 @@ pango_ot_info_find_feature  (PangoOTInfo      *info,
 {
   HB_ScriptList *script_list;
   HB_FeatureList *feature_list;
-  HB_Script *script;
+  HB_ScriptTable *script;
   HB_LangSys *lang_sys;
 
   int i;
@@ -623,7 +623,7 @@ pango_ot_info_find_feature  (PangoOTInfo      *info,
 
   for (i = 0; i < lang_sys->FeatureCount; i++)
     {
-      FT_UShort index = lang_sys->FeatureIndex[i];
+      HB_UShort index = lang_sys->FeatureIndex[i];
 
       if (feature_list->FeatureRecord[index].FeatureTag == feature_tag)
 	{
@@ -690,7 +690,7 @@ pango_ot_info_list_languages (PangoOTInfo      *info,
 {
   PangoOTTag *result;
   HB_ScriptList *script_list;
-  HB_Script *script;
+  HB_ScriptTable *script;
   int i;
 
   g_return_val_if_fail (PANGO_IS_OT_INFO (info), NULL);
@@ -745,7 +745,7 @@ pango_ot_info_list_features  (PangoOTInfo      *info,
 
   HB_ScriptList *script_list;
   HB_FeatureList *feature_list;
-  HB_Script *script;
+  HB_ScriptTable *script;
   HB_LangSys *lang_sys;
 
   int i;
@@ -778,7 +778,7 @@ pango_ot_info_list_features  (PangoOTInfo      *info,
 
   for (i = 0; i < lang_sys->FeatureCount; i++)
     {
-      FT_UShort index = lang_sys->FeatureIndex[i];
+      HB_UShort index = lang_sys->FeatureIndex[i];
 
       result[i] = feature_list->FeatureRecord[index].FeatureTag;
     }
